/*
 * YouGrabber
 *
 * A lightweight, ncurses based, multi-threaded command-line YouTube.com
 * video downloader.
 *
 * Copyright (C) 2006-2007 Quetzy Garcia <quetzyg@users.sourceforge.net>
 * http://yougrabber.sourceforge.net/
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "yg.h"

YGconfig *getcfg(void)
{
	YGconfig *cfg = NULL;
	char line[256];
	char buf[256];
	unsigned n;
	unsigned pos;

	cfg = (YGconfig *) malloc(sizeof(YGconfig));

	if (!cfg)
		return NULL;

	/* config settings */
	strncpy(cfg->path, "", sizeof(cfg->path));

	/* connection settings */
	strncpy(cfg->proxy.host, "", sizeof(cfg->proxy.host));
	cfg->proxy.port = 8080;
	cfg->proxy.type = CURLPROXY_HTTP;
	strncpy(cfg->proxy.username, "", sizeof(cfg->proxy.username));
	strncpy(cfg->proxy.password, "", sizeof(cfg->proxy.password));

	/* search settings */
	strncpy(cfg->video.base_url, "http://www.youtube.com/get_video?",
		sizeof(cfg->video.base_url));
	strncpy(cfg->video.search.title.string, "<title>",
		sizeof(cfg->video.search.title.string));
	strncpy(cfg->video.search.title.delim, "><",
		sizeof(cfg->video.search.title.delim));
	strncpy(cfg->video.search.url.string, "var swfArgs =",
		sizeof(cfg->video.search.url.string));
	strncpy(cfg->video.search.url.delim, "{}",
		sizeof(cfg->video.search.url.delim));

	snprintf(buf, sizeof(buf), "%s/%s", getenv("HOME"), YG_CFG_FILE);
	FILE *stream = fopen(buf, "r");

	if (!stream)
		return cfg;
	else
		strncpy(cfg->path, buf, sizeof(cfg->path));

	while (fgets(line, sizeof(line), stream)) {
		if (feof(stream))
			break;

		/* strip comments */
		for (n = 0; n < strlen(line); ++n)
			if (strchr("#", line[n]))
				break;

		snprintf(buf, sizeof(char)*(n+1), line);

		/* strip spaces */
		for (pos = n = 0; n < strlen(buf); ++n)
			if (!isspace(buf[n]))
				line[pos++] = buf[n];

		line[pos] = 0;

		/* after the string is clean, parse it */
		if (strlen(line)) {
			if (strstr(line, "BASE_URL="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->video.base_url, line,
						sizeof(cfg->video.base_url));

			if (strstr(line, "TITLE_STRING="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->video.search.title.string, line,
						sizeof(cfg->video.search.title.string));

			if (strstr(line, "TITLE_STRING_DELIM="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->video.search.title.delim, line,
						sizeof(cfg->video.search.title.delim));

			if (strstr(line, "URL_STRING="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->video.search.url.string, line,
						sizeof(cfg->video.search.url.string));

			if (strstr(line, "URL_STRING_DELIM="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->video.search.url.delim, line,
						sizeof(cfg->video.search.url.delim));

			if (strstr(line, "PROXY_HOST="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->proxy.host, line, sizeof(cfg->proxy.host));

			if (strstr(line, "PROXY_PORT="))
				if (strlen(strcut(line, '[', ']', 1)))
					cfg->proxy.port=atoi(line);

			if (strstr(line, "PROXY_TYPE="))
				if (strlen(strtoupper(strcut(line, '[', ']', 1)))) {
					if (!strcmp(line, "HTTP"))
						cfg->proxy.type = CURLPROXY_HTTP;

					if (!strcmp(line, "SOCKS4"))
						cfg->proxy.type = CURLPROXY_SOCKS4;

					if (!strcmp(line, "SOCKS5"))
						cfg->proxy.type = CURLPROXY_SOCKS5;
				}

			if (strstr(line, "PROXY_USR="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->proxy.username, line,
						sizeof(cfg->proxy.username));

			if (strstr(line, "PROXY_PWD="))
				if (strlen(strcut(line, '[', ']', 1)))
					strncpy(cfg->proxy.password, line,
						sizeof(cfg->proxy.password));
		}
	}

	fclose(stream);

	return cfg;
}
