/*
 * YouGrabber
 *
 * A lightweight, ncurses based, multi-threaded command-line YouTube.com
 * video downloader.
 *
 * Copyright (C) 2006-2007 Quetzy Garcia <quetzyg@users.sourceforge.net>
 * http://yougrabber.sourceforge.net/
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <ctype.h>
#include <libgen.h>
#include <string.h>
#include <errno.h>
#include <pthread.h>
#include <curl/curl.h>
#include <ncurses.h>
#include <panel.h>

#define _GNU_SOURCE
#define REENTRANT

/* constant program info */
#define YG_STRING	"YouGrabber"
#define YG_VERSION	"0.20.2"
#define YG_AUTHOR	"Quetzy Garcia"
#define YG_EMAIL	"quetzyg@users.sourceforge.net"
#define YG_URL		"http://yougrabber.sourceforge.net/"
#define YG_CFG_FILE	".yg.conf"

/* downloads in progress */
extern unsigned dip;

/* configuration data structure */
typedef struct {
	char path[64];

	struct {
		char host[128];
		long port;
		long type;
		char username[32];
		char password[32];
	} proxy;

	struct {
		char base_url[64];

		struct {
			struct {
				char string[32];
				char delim[2];
			} title;

			struct {
				char string[32];
				char delim[2];
			} url;
		} search;
	} video;
} YGconfig;

/* download data structure */
typedef struct {
	char title[64];

	YGconfig *config;

	struct {
		char name[72];
		double size;
	} file;

	struct {
		char url[256];
		double time;
		double speed;
	} connection;

	pthread_t tid;
	WINDOW *window;
	PANEL *panel;
} YGdownload;

/* string cutter */
char *strcut(char *, char, char, unsigned);

/* string to upper case */
char *strtoupper(char *);

/* make a file name from a string */
char *mkfilename(char *, char *, char []);

/* download notifier/cleaner */
void dipclean(void);

/* video downloader */
int grab(YGdownload *);

/* configuration parser */
YGconfig *getcfg(void);
